@@ -88,10 +88,10 @@ type 'a ocaml_content
     pages. *)
 module Html :
   Eliom_registration_sigs.S_with_create
-    with type page = Html_types.html Eliom_content.Html.elt
-     and type options = unit
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
+  with type page = Html_types.html Eliom_content.Html.elt
+   and type options = unit
+   and type return = Eliom_service.non_ocaml
+   and type result = browser_content kind
 
 (** {2 Eliom client/server applications} *)
 
@@ -110,8 +110,8 @@ val default_appl_service_options : appl_service_options
     {!appl_service_options}. *)
 
 module type APP = sig
-  val application_script
-    :  ?defer:bool
+  val application_script :
+     ?defer:bool
     -> ?async:bool
     -> unit
     -> [> `Script] Eliom_content.Html.elt
@@ -140,18 +140,18 @@ module type APP = sig
 
   include
     Eliom_registration_sigs.S_with_create
-      with type page = Html_types.html Eliom_content.Html.elt
-       and type options = appl_service_options
-       and type return = Eliom_service.non_ocaml
-       and type result = app_id application_content kind
+    with type page = Html_types.html Eliom_content.Html.elt
+     and type options = appl_service_options
+     and type return = Eliom_service.non_ocaml
+     and type result = app_id application_content kind
 
   (**/**)
 
   val typed_name : app_id application_name
 end
 
-val transform_global_app_uri
-  : (Eliom_content.Html.uri -> Eliom_content.Html.uri) ref
+val transform_global_app_uri :
+  (Eliom_content.Html.uri -> Eliom_content.Html.uri) ref
 (** Function to modify the global_app URI for some obscure reason *)
 
 (** Functor for application creation.
@@ -169,10 +169,10 @@ end
 
 module Eliom_tmpl (App : APP) (Tmpl_param : TMPL_PARAMS) :
   Eliom_registration_sigs.S_with_create
-    with type page = Tmpl_param.t
-     and type options = appl_service_options
-     and type return = Eliom_service.non_ocaml
-     and type result = App.app_id application_content kind
+  with type page = Tmpl_param.t
+   and type options = appl_service_options
+   and type return = Eliom_service.non_ocaml
+   and type result = App.app_id application_content kind
 
 (** {3 Services returning HTML (or other TyXML) fragments} *)
 
@@ -183,13 +183,13 @@ module Eliom_tmpl (App : APP) (Tmpl_param : TMPL_PARAMS) :
     fragments. *)
 module Flow5 :
   Eliom_registration_sigs.S_with_create
-    with type page = Html_types.flow5 Eliom_content.Html.elt list
-     and type options = unit
-     and type return = Eliom_service.non_ocaml
-     and type result = block_content kind
+  with type page = Html_types.flow5 Eliom_content.Html.elt list
+   and type options = unit
+   and type return = Eliom_service.non_ocaml
+   and type result = block_content kind
 
 (*
-(** Eliom service registration for services that return fragments of
+   (** Eliom service registration for services that return fragments of
     TyXML's tree. *)
 module Make_typed_xml_registration
   (Xml: Xml_sigs.Iterable)
@@ -209,10 +209,10 @@ module Make_typed_xml_registration
     and the content type is always [text/html]. *)
 module Html_text :
   Eliom_registration_sigs.S_with_create
-    with type page = string
-     and type options = unit
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
+  with type page = string
+   and type options = unit
+   and type return = Eliom_service.non_ocaml
+   and type result = browser_content kind
 
 (** Eliom service registration for services that returns CSS. The page
     content is a [string] that must contains valid CSS and the content
@@ -220,10 +220,10 @@ module Html_text :
     "Cache-policy: max-age" header value to be sent. *)
 module CssText :
   Eliom_registration_sigs.S_with_create
-    with type page = string
-     and type options = int
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
+  with type page = string
+   and type options = int
+   and type return = Eliom_service.non_ocaml
+   and type result = browser_content kind
 
 (** {2 Other kinds of services} *)
 
@@ -237,34 +237,34 @@ module CssText :
     Content] will be sent to the server. *)
 module Action :
   Eliom_registration_sigs.S_with_create
-    with type return = Eliom_service.non_ocaml
-     and type page = unit
-     and type options = [`Reload | `NoReload]
-     and type result = browser_content kind
+  with type return = Eliom_service.non_ocaml
+   and type page = unit
+   and type options = [`Reload | `NoReload]
+   and type result = browser_content kind
 
 (** Similar to {!Actions} with [`NoReload] option. *)
 module Unit :
   Eliom_registration_sigs.S_with_create
-    with type page = unit
-     and type options = unit
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
+  with type page = unit
+   and type options = unit
+   and type return = Eliom_service.non_ocaml
+   and type result = browser_content kind
 
 (** Auxiliarry type to hide non-interesting type parameters *)
 type _ redirection =
   | Redirection :
       ( unit
-      , unit
-      , Eliom_service.get
-      , _
-      , _
-      , _
-      , _
-      , [`WithoutSuffix]
-      , unit
-      , unit
-      , 'a )
-      Eliom_service.t
+        , unit
+        , Eliom_service.get
+        , _
+        , _
+        , _
+        , _
+        , [`WithoutSuffix]
+        , unit
+        , unit
+        , 'a )
+        Eliom_service.t
       -> 'a redirection
 
 (** Eliom service registration for services that returns a
@@ -284,18 +284,18 @@ type _ redirection =
 module Redirection : sig
   include
     Eliom_registration_sigs.S_poly_with_create
-      with type 'a page = 'a redirection
-       and type options =
-            [ `MovedPermanently
-            | `Found
-            | `SeeOther
-            | `NotNodifed
-            | `UseProxy
-            | `TemporaryRedirect ]
-       and type 'a return = 'a
+    with type 'a page = 'a redirection
+     and type options =
+      [ `MovedPermanently
+      | `Found
+      | `SeeOther
+      | `NotNodifed
+      | `UseProxy
+      | `TemporaryRedirect ]
+     and type 'a return = 'a
 
-  val send
-    :  ?options:options
+  val send :
+     ?options:options
     -> ?charset:string
     -> ?code:int
     -> ?content_type:string
@@ -316,16 +316,16 @@ end
     {!Redirections} for a detailed description. *)
 module String_redirection :
   Eliom_registration_sigs.S_with_create
-    with type page = Eliom_lib.Url.uri
-     and type options =
-          [ `MovedPermanently
-          | `Found
-          | `SeeOther
-          | `NotNodifed
-          | `UseProxy
-          | `TemporaryRedirect ]
-     and type return = Eliom_service.non_ocaml
-     and type result = browser_content kind
+  with type page = Eliom_lib.Url.uri
+   and type options =
+    [ `MovedPermanently
+    | `Found
+    | `SeeOther
+    | `NotNodifed
+    | `UseProxy
+    | `TemporaryRedirect ]
+   and type return = Eliom_service.non_ocaml
+   and type result = browser_content kind
 
 (** Eliom service registration for services that returns file
     contents. The value returned by service handlers is the name of
@@ -341,10 +341,10 @@ module File : sig
 
   include
     Eliom_registration_sigs.S_with_create
-      with type page = string
-       and type options = int
-       and type return = Eliom_service.non_ocaml
-       and type result = browser_content kind
+    with type page = string
+     and type options = int
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 end
 
 (** Same as file but makes possible to specify the content type for
@@ -358,20 +358,20 @@ module File_ct : sig
 
   include
     Eliom_registration_sigs.S_with_create
-      with type page = string * string
-       and type options = int
-       and type return = Eliom_service.non_ocaml
-       and type result = browser_content kind
+    with type page = string * string
+     and type options = int
+     and type return = Eliom_service.non_ocaml
+     and type result = browser_content kind
 end
 
 (** Eliom service registration for services that send marshalled OCaml
     values. *)
 module Ocaml :
   Eliom_registration_sigs.S_poly_with_create_with_send
-    with type 'a page = 'a
-     and type options = unit
-     and type 'a return = 'a Eliom_service.ocaml
-     and type 'a result = 'a ocaml_content kind
+  with type 'a page = 'a
+   and type options = unit
+   and type 'a return = 'a Eliom_service.ocaml
+   and type 'a result = 'a ocaml_content kind
 
 (** Eliom service registration for services that choose dynamically
     what they want to send. The content is created using for example
@@ -381,13 +381,13 @@ module Ocaml :
     send>>%} *)
 module Any :
   Eliom_registration_sigs.S_poly_with_create_with_send
-    with type 'a page = 'a kind
-     and type options = unit
-     and type 'a return = Eliom_service.non_ocaml
-     and type 'a result = 'a kind
+  with type 'a page = 'a kind
+   and type options = unit
+   and type 'a return = Eliom_service.non_ocaml
+   and type 'a result = 'a kind
 
-val appl_self_redirect
-  :  ('page -> [< 'a application_content | browser_content] kind Lwt.t)
+val appl_self_redirect :
+   ('page -> [< 'a application_content | browser_content] kind Lwt.t)
   -> 'page
   -> 'appl application_content kind Lwt.t
 (** The function [appl_self_redirect send page] is an helper function
@@ -410,13 +410,13 @@ val appl_self_redirect
     "Cache-policy: max-age" header value to be sent. *)
 module String :
   Eliom_registration_sigs.S_with_create
-    with type page = string * string
-     and type options = int
-     and type return = Eliom_service.non_ocaml
-     and type result = unknown_content kind
+  with type page = string * string
+   and type options = int
+   and type return = Eliom_service.non_ocaml
+   and type result = unknown_content kind
 
 (*
-(** Eliom service registration for services that returns "byte"
+   (** Eliom service registration for services that returns "byte"
     contents with {% <<a_api project="ocsigenserver" text="Ocsigen's
     streams"| module Ocsigen_stream>>%}. The page content is a pair
     [(stream_creator_list, content_type)]. See also {!String} for
@@ -442,16 +442,17 @@ module Streamlist : Eliom_registration_sigs.S_with_create
     <<a_manual project="tutorial" chapter="interaction"| Eliom
     tutorial>>%} for example. *)
 module Customize
-    (R : Eliom_registration_sigs.S_with_create) (T : sig
-      type page
+    (R : Eliom_registration_sigs.S_with_create)
+    (T : sig
+       type page
 
-      val translate : page -> R.page Lwt.t
-    end) :
+       val translate : page -> R.page Lwt.t
+     end) :
   Eliom_registration_sigs.S_with_create
-    with type options = R.options
-     and type return = R.return
-     and type page = T.page
-     and type result = R.result
+  with type options = R.options
+   and type return = R.return
+   and type page = T.page
+   and type result = R.result
 
 (** {2 Using your own error pages} *)
 
