@@ -44,8 +44,8 @@ let getperssessgrp = Eliom_common.getperssessgrp
 module type MEMTAB = sig
   type group_of_group_data
 
-  val add
-    :  ?set_max:int
+  val add :
+     ?set_max:int
     -> Eliom_common.sitedata
     -> string
     -> Eliom_common.cookie_level Eliom_common.sessgrp
@@ -54,20 +54,20 @@ module type MEMTAB = sig
   val remove : 'a Ocsigen_cache.Dlist.node -> unit
   val remove_group : Eliom_common.cookie_level Eliom_common.sessgrp -> unit
 
-  val find
-    :  [< Eliom_common.cookie_level] Eliom_common.sessgrp
+  val find :
+     [< Eliom_common.cookie_level] Eliom_common.sessgrp
     -> string Ocsigen_cache.Dlist.t
   (** returns the dlist containing all session group elements *)
 
-  val find_node_in_group_of_groups
-    :  Eliom_common.cookie_level Eliom_common.sessgrp
+  val find_node_in_group_of_groups :
+     Eliom_common.cookie_level Eliom_common.sessgrp
     -> group_of_group_data option
   (** Groups of browser sessions belongs to a group of groups.
         As these groups are not associated to a cookie,
         we put this information here. *)
 
-  val move
-    :  ?set_max:int
+  val move :
+     ?set_max:int
     -> Eliom_common.sitedata
     -> string Ocsigen_cache.Dlist.node
     -> Eliom_common.cookie_level Eliom_common.sessgrp
@@ -80,40 +80,40 @@ module type MEMTAB = sig
 end
 
 module GroupTable = Hashtbl.Make (struct
-  type t = Eliom_common.cookie_level Eliom_common.sessgrp
+    type t = Eliom_common.cookie_level Eliom_common.sessgrp
 
-  let equal = ( = )
-  let hash = Hashtbl.hash
-end)
+    let equal = ( = )
+    let hash = Hashtbl.hash
+  end)
 
 module Make (A : sig
-  type group_of_group_data
+    type group_of_group_data
 
-  val table
-    : (group_of_group_data option * string Ocsigen_cache.Dlist.t) GroupTable.t
+    val table :
+      (group_of_group_data option * string Ocsigen_cache.Dlist.t) GroupTable.t
 
-  val close_session : Eliom_common.sitedata -> string -> unit
-  val max_tab_per_session : Eliom_common.sitedata -> int
-  val max_session_per_group : Eliom_common.sitedata -> int
-  val max_session_per_ip : Eliom_common.sitedata -> int
+    val close_session : Eliom_common.sitedata -> string -> unit
+    val max_tab_per_session : Eliom_common.sitedata -> int
+    val max_session_per_group : Eliom_common.sitedata -> int
+    val max_session_per_ip : Eliom_common.sitedata -> int
 
-  val clean_session
-    :  Eliom_common.sitedata
-    -> GroupTable.key
-    -> (GroupTable.key -> group_of_group_data option)
-    -> (string Ocsigen_cache.Dlist.node -> unit)
-    -> (group_of_group_data -> unit)
-    -> unit
+    val clean_session :
+       Eliom_common.sitedata
+      -> GroupTable.key
+      -> (GroupTable.key -> group_of_group_data option)
+      -> (string Ocsigen_cache.Dlist.node -> unit)
+      -> (group_of_group_data -> unit)
+      -> unit
 
-  val node_of_group_of_group_data
-    :  group_of_group_data
-    -> [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
+    val node_of_group_of_group_data :
+       group_of_group_data
+      -> [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
 
-  val create_group_of_group_data
-    :  Eliom_common.sitedata
-    -> [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
-    -> group_of_group_data
-end) : MEMTAB with type group_of_group_data = A.group_of_group_data = struct
+    val create_group_of_group_data :
+       Eliom_common.sitedata
+      -> [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
+      -> group_of_group_data
+  end) : MEMTAB with type group_of_group_data = A.group_of_group_data = struct
   type group_of_group_data = A.group_of_group_data
 
   let grouptable = A.table
@@ -166,28 +166,28 @@ end) : MEMTAB with type group_of_group_data = A.group_of_group_data = struct
       let cl = Ocsigen_cache.Dlist.create size in
       Ocsigen_cache.Dlist.set_finaliser_after
         (fun node ->
-          (* Finaliser of sessions and client processes *)
-          let name = Ocsigen_cache.Dlist.value node in
-          (* First we close all subsessions
+           (* Finaliser of sessions and client processes *)
+           let name = Ocsigen_cache.Dlist.value node in
+           (* First we close all subsessions
              (that is, all sessions in the group associated to the session) *)
-          (match cookie_level with
-          (*            | `Session_group -> assert false
+           (match cookie_level with
+           (*            | `Session_group -> assert false
               As there is no table of groups of groups
               (only one group of groups for each site),
               the finaliser for these groups is created in eliommod.ml *)
-          | `Session (* We are closing a browser session *) ->
-              (* First we close all tab sessions in the session (subgrp): *)
-              let subgrp =
-                make_full_named_group_name_ ~cookie_level:`Client_process
-                  sitedata name
-              in
-              remove_group subgrp
-          | `Client_process (* We are closing a tab session *) -> ());
-          (* Then we close all session tables: *)
-          A.close_session sitedata name;
-          (* If the dlist is empty, we remove it from the group table
+           | `Session (* We are closing a browser session *) ->
+               (* First we close all tab sessions in the session (subgrp): *)
+               let subgrp =
+                 make_full_named_group_name_ ~cookie_level:`Client_process
+                   sitedata name
+               in
+               remove_group subgrp
+           | `Client_process (* We are closing a tab session *) -> ());
+           (* Then we close all session tables: *)
+           A.close_session sitedata name;
+           (* If the dlist is empty, we remove it from the group table
              (and possibly close the group itself): *)
-          remove_if_empty sitedata sess_grp cl)
+           remove_if_empty sitedata sess_grp cl)
         cl;
       let node_in_group_of_group =
         match cookie_level with
@@ -240,13 +240,13 @@ end) : MEMTAB with type group_of_group_data = A.group_of_group_data = struct
 end
 
 module Data = Make (struct
-  type group_of_group_data =
-    [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
+    type group_of_group_data =
+      [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
 
-  let table
-      : (group_of_group_data option * string Ocsigen_cache.Dlist.t) GroupTable.t
-    =
-    (* The table associates the dlist for a group
+    let table :
+        (group_of_group_data option * string Ocsigen_cache.Dlist.t) GroupTable.t
+      =
+      (* The table associates the dlist for a group
          to a full session group name.
          It work both for groups of tab sessions and
          groups of browser sessions.
@@ -260,28 +260,28 @@ module Data = Make (struct
          which corresponds to the node of that group in the group
          of groups (one group of groups for each site).
       *)
-    GroupTable.create 100
+      GroupTable.create 100
 
-  let close_session sitedata sess_id =
-    Eliom_common.SessionCookies.remove sitedata.Eliom_common.session_data
-      sess_id;
-    (* iterate on all session data tables: *)
-    sitedata.Eliom_common.remove_session_data sess_id
-  (* see also in eliommod.ml if you modify this *)
+    let close_session sitedata sess_id =
+      Eliom_common.SessionCookies.remove sitedata.Eliom_common.session_data
+        sess_id;
+      (* iterate on all session data tables: *)
+      sitedata.Eliom_common.remove_session_data sess_id
+    (* see also in eliommod.ml if you modify this *)
 
-  let max_tab_per_session sitedata =
-    fst sitedata.Eliom_common.max_volatile_data_tab_sessions_per_group
+    let max_tab_per_session sitedata =
+      fst sitedata.Eliom_common.max_volatile_data_tab_sessions_per_group
 
-  let max_session_per_group sitedata =
-    fst sitedata.Eliom_common.max_volatile_data_sessions_per_group
+    let max_session_per_group sitedata =
+      fst sitedata.Eliom_common.max_volatile_data_sessions_per_group
 
-  let max_session_per_ip sitedata =
-    fst sitedata.Eliom_common.max_volatile_data_sessions_per_subnet
+    let max_session_per_ip sitedata =
+      fst sitedata.Eliom_common.max_volatile_data_sessions_per_subnet
 
-  let clean_session sitedata sess_grp find_node_in_group_of_groups remove1
-      remove2
-    =
-    (* We removed the last session from a group.
+    let clean_session sitedata sess_grp find_node_in_group_of_groups remove1
+        remove2
+      =
+      (* We removed the last session from a group.
          Do we want to close the group completely?
          - For volatile browser sessions, yes.
          We do not keep group data when there is no session in the group.
@@ -294,62 +294,62 @@ Besides, volatile sessions are (hopefully) going to disappear soon.
          bound in tables and is not in a group (like in Eliommod_gc)
          (means that we do not use the browser session).
       *)
-    (*VVV See also in Eliommod_gc and
+      (*VVV See also in Eliommod_gc and
   Eliom_state.close_volatile_session_if_empty.
   Should we use this function here?
-*)
-    (*VVV remove is not polymorphic enough -> remove1 remove2 *)
-    match (sess_grp : GroupTable.key) with
-    | _, `Client_process, Left sess_id -> (
-      try
-        let {Eliom_common.Data_cookie.session_group; session_group_node; _} =
-          Eliom_common.SessionCookies.find sitedata.Eliom_common.session_data
-            sess_id
-        in
-        match !session_group with
-        | _, `Session, Right _
-        (* no group *)
-          when sitedata.Eliom_common.not_bound_in_data_tables sess_id ->
-            remove1 session_group_node
-        | _ -> ()
-      with Not_found -> ())
-    | _, `Session, _ -> (
-      match find_node_in_group_of_groups sess_grp with
-      | Some node -> remove2 node
-      | None -> ())
-    | _ -> ()
+      *)
+      (*VVV remove is not polymorphic enough -> remove1 remove2 *)
+      match (sess_grp : GroupTable.key) with
+      | _, `Client_process, Left sess_id -> (
+        try
+          let {Eliom_common.Data_cookie.session_group; session_group_node; _} =
+            Eliom_common.SessionCookies.find sitedata.Eliom_common.session_data
+              sess_id
+          in
+          match !session_group with
+          | _, `Session, Right _
+          (* no group *)
+            when sitedata.Eliom_common.not_bound_in_data_tables sess_id ->
+              remove1 session_group_node
+          | _ -> ()
+        with Not_found -> ())
+      | _, `Session, _ -> (
+        match find_node_in_group_of_groups sess_grp with
+        | Some node -> remove2 node
+        | None -> ())
+      | _ -> ()
 
-  let node_of_group_of_group_data x = x
-  let create_group_of_group_data _ x = x
-end)
+    let node_of_group_of_group_data x = x
+    let create_group_of_group_data _ x = x
+  end)
 
 module Serv = Make (struct
-  type group_of_group_data =
-    Eliom_common.tables ref
-    * [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
+    type group_of_group_data =
+      Eliom_common.tables ref
+      * [`Session] Eliom_common.sessgrp Ocsigen_cache.Dlist.node
 
-  let table
-      : (group_of_group_data option * string Ocsigen_cache.Dlist.t) GroupTable.t
-    =
-    GroupTable.create 100
+    let table :
+        (group_of_group_data option * string Ocsigen_cache.Dlist.t) GroupTable.t
+      =
+      GroupTable.create 100
 
-  let close_session sitedata sess_id =
-    Eliom_common.SessionCookies.remove sitedata.Eliom_common.session_services
-      sess_id
+    let close_session sitedata sess_id =
+      Eliom_common.SessionCookies.remove sitedata.Eliom_common.session_services
+        sess_id
 
-  let max_tab_per_session sitedata =
-    fst sitedata.Eliom_common.max_service_tab_sessions_per_group
+    let max_tab_per_session sitedata =
+      fst sitedata.Eliom_common.max_service_tab_sessions_per_group
 
-  let max_session_per_group sitedata =
-    fst sitedata.Eliom_common.max_service_sessions_per_group
+    let max_session_per_group sitedata =
+      fst sitedata.Eliom_common.max_service_sessions_per_group
 
-  let max_session_per_ip sitedata =
-    fst sitedata.Eliom_common.max_service_sessions_per_subnet
+    let max_session_per_ip sitedata =
+      fst sitedata.Eliom_common.max_service_sessions_per_subnet
 
-  let clean_session sitedata sess_grp find_node_in_group_of_groups remove1
-      remove2
-    =
-    (* We removed the last session from a group.
+    let clean_session sitedata sess_grp find_node_in_group_of_groups remove1
+        remove2
+      =
+      (* We removed the last session from a group.
          Do we want to close the group completely?
          - For volatile browser sessions, yes.
          We do not keep group data when there is no session in the group.
@@ -362,38 +362,38 @@ Besides, volatile sessions are (hopefully) going to disappear soon.
          in the browser service table.
          (means that we do not use the browser session).
       *)
-    (*VVV We close even if browser session is in a group.
+      (*VVV We close even if browser session is in a group.
   It is not coherent with data sessions. *)
-    (*VVV See also in Eliommod_gc and
+      (*VVV See also in Eliommod_gc and
   Eliom_state.close_service_session_if_empty.
   Should we use this function here?
-*)
-    (*VVV remove is not polymorphic enough -> remove1 remove2 *)
-    match (sess_grp : GroupTable.key) with
-    | _, `Client_process, Left sess_id -> (
-      try
-        let { Eliom_common.Service_cookie.session_table = tables
-            ; session_group_node
-            ; _ }
-          =
-          Eliom_common.SessionCookies.find
-            sitedata.Eliom_common.session_services sess_id
-        in
-        if Eliom_common.service_tables_are_empty tables
-        then remove1 session_group_node
-      with Not_found -> ())
-    | _, `Session, _ -> (
-      match find_node_in_group_of_groups sess_grp with
-      | Some node -> remove2 node
-      | None -> ())
-    | _ -> ()
+      *)
+      (*VVV remove is not polymorphic enough -> remove1 remove2 *)
+      match (sess_grp : GroupTable.key) with
+      | _, `Client_process, Left sess_id -> (
+        try
+          let { Eliom_common.Service_cookie.session_table = tables
+              ; session_group_node
+              ; _ }
+            =
+            Eliom_common.SessionCookies.find
+              sitedata.Eliom_common.session_services sess_id
+          in
+          if Eliom_common.service_tables_are_empty tables
+          then remove1 session_group_node
+        with Not_found -> ())
+      | _, `Session, _ -> (
+        match find_node_in_group_of_groups sess_grp with
+        | Some node -> remove2 node
+        | None -> ())
+      | _ -> ()
 
-  let node_of_group_of_group_data = snd
+    let node_of_group_of_group_data = snd
 
-  let create_group_of_group_data sitedata x =
-    ref (Eliom_common.new_service_session_tables sitedata), x
-  (*VVV Check when the table is collected *)
-end)
+    let create_group_of_group_data sitedata x =
+      ref (Eliom_common.new_service_session_tables sitedata), x
+    (*VVV Check when the table is collected *)
+  end)
 
 type nbmax = Val of int | Default | Nolimit
 
@@ -426,9 +426,9 @@ module Pers = struct
     | Some g ->
         Lwt.catch
           (fun () ->
-            !!grouptable >>= fun grouptable ->
-            Ocsipersist.find grouptable (Eliom_common.string_of_perssessgrp g)
-            >>= fun (_, a) -> Lwt.return a)
+             !!grouptable >>= fun grouptable ->
+             Ocsipersist.find grouptable (Eliom_common.string_of_perssessgrp g)
+             >>= fun (_, a) -> Lwt.return a)
           (function Not_found -> Lwt.return_nil | e -> Lwt.fail e)
 
   let add ?set_max defaultmax sess_id sess_grp =
@@ -437,34 +437,34 @@ module Pers = struct
         let sg = Eliom_common.string_of_perssessgrp sg in
         Lwt.catch
           (fun () ->
-            !!grouptable >>= fun grouptable ->
-            Ocsipersist.find grouptable sg >>= fun (max2, cl) ->
-            let max, newmax =
-              match set_max with
-              | None ->
-                  ( (match max2 with
-                    | Default -> defaultmax
-                    | Nolimit -> None
-                    | Val m -> Some m)
-                  , max2 )
-              | Some None -> None, Nolimit
-              | Some (Some v) -> Some v, Val v
-            in
-            let cl, toclose = cut max cl in
-            Ocsipersist.replace_if_exists grouptable sg (newmax, sess_id :: cl)
-            >>= fun () -> Lwt.return toclose)
+             !!grouptable >>= fun grouptable ->
+             Ocsipersist.find grouptable sg >>= fun (max2, cl) ->
+             let max, newmax =
+               match set_max with
+               | None ->
+                   ( (match max2 with
+                     | Default -> defaultmax
+                     | Nolimit -> None
+                     | Val m -> Some m)
+                   , max2 )
+               | Some None -> None, Nolimit
+               | Some (Some v) -> Some v, Val v
+             in
+             let cl, toclose = cut max cl in
+             Ocsipersist.replace_if_exists grouptable sg (newmax, sess_id :: cl)
+             >>= fun () -> Lwt.return toclose)
           (function
-            | Not_found ->
-                let max =
-                  match set_max with
-                  | None -> Default
-                  | Some None -> Nolimit
-                  | Some (Some v) -> Val v
-                in
-                !!grouptable >>= fun grouptable ->
-                Ocsipersist.add grouptable sg (max, [sess_id]) >>= fun () ->
-                Lwt.return_nil
-            | e -> Lwt.fail e)
+             | Not_found ->
+                 let max =
+                   match set_max with
+                   | None -> Default
+                   | Some None -> Nolimit
+                   | Some (Some v) -> Val v
+                 in
+                 !!grouptable >>= fun grouptable ->
+                 Ocsipersist.add grouptable sg (max, [sess_id]) >>= fun () ->
+                 Lwt.return_nil
+             | e -> Lwt.fail e)
     | None -> Lwt.return_nil
 
   let rec remove_group ~cookie_level sitedata sess_grp =
@@ -474,49 +474,49 @@ module Pers = struct
     (*VVV Check this carefully!!!! Verify the order of actions. *)
     Lwt.catch
       (fun () ->
-        (* First we close all sessions in the group *)
-        find sess_grp >>= fun cl ->
-        Lwt_list.iter_p
-          (close_persistent_session2
-             ~cookie_level:
-               (match cookie_level with
-               | `Client_process _ -> `Client_process
-               | `Session -> `Session)
-             sitedata None)
-          cl
-        (* None because we will close the group *)
-        >>= fun () ->
-        (* Then, we remove group data: *)
-        (match sess_grp with
-        | None -> Lwt.return_unit
-        | Some sg -> (
-          match Eliom_common.getperssessgrp sg with
-          | _, _, Right _ ->
-              (* No group has been set. No group table.
+         (* First we close all sessions in the group *)
+         find sess_grp >>= fun cl ->
+         Lwt_list.iter_p
+           (close_persistent_session2
+              ~cookie_level:
+                (match cookie_level with
+                | `Client_process _ -> `Client_process
+                | `Session -> `Session)
+              sitedata None)
+           cl
+         (* None because we will close the group *)
+         >>= fun () ->
+         (* Then, we remove group data: *)
+         (match sess_grp with
+           | None -> Lwt.return_unit
+           | Some sg -> (
+             match Eliom_common.getperssessgrp sg with
+             | _, _, Right _ ->
+                 (* No group has been set. No group table.
                  Data associated to default (automatic) groups
                  is removed when closing associated sessions. *)
-              Lwt.return_unit
-          | _, _, Left group_name -> (
-              Eliom_common.Persistent_tables.remove_key_from_all_tables
-                group_name
-              >>= fun () ->
-              (* If it is associated to a session,
+                 Lwt.return_unit
+             | _, _, Left group_name -> (
+                 Eliom_common.Persistent_tables.remove_key_from_all_tables
+                   group_name
+                 >>= fun () ->
+                 (* If it is associated to a session,
                  we remove the session from its group,
                  and we remove cookie info: *)
-              match cookie_level with
-              | `Client_process grp ->
-                  (* We are closing a browser session,
+                 match cookie_level with
+                 | `Client_process grp ->
+                     (* We are closing a browser session,
                                            belonging to the group grp *)
-                  (* group_name is the cookie value *)
-                  remove sitedata group_name grp
-              | _ -> Lwt.return_unit)))
-        >>= fun () ->
-        (* Then, we remove group from group table: *)
-        match sess_grp with
-        | Some sg ->
-            let sg = Eliom_common.string_of_perssessgrp sg in
-            !!grouptable >>= fun grouptable -> Ocsipersist.remove grouptable sg
-        | None -> Lwt.return_unit)
+                     (* group_name is the cookie value *)
+                     remove sitedata group_name grp
+                 | _ -> Lwt.return_unit)))
+         >>= fun () ->
+         (* Then, we remove group from group table: *)
+         match sess_grp with
+         | Some sg ->
+             let sg = Eliom_common.string_of_perssessgrp sg in
+             !!grouptable >>= fun grouptable -> Ocsipersist.remove grouptable sg
+         | None -> Lwt.return_unit)
       (function Not_found -> Lwt.return_unit | e -> Lwt.fail e)
 
   (* close a persistent session (tab or browser)
@@ -526,17 +526,17 @@ module Pers = struct
     (*VVV Optimize the number of marshal/unmarshal (getperssessgrp) *)
     Lwt.catch
       (fun () ->
-        match cookie_level with
-        | `Client_process ->
-            (* We remove the session from its group: *)
-            remove sitedata cookie fullsessgrp >>= fun () ->
-            (* Then, we remove session data: *)
-            Eliom_common.Persistent_tables.remove_key_from_all_tables cookie
-        | `Session ->
-            remove_group ~cookie_level:(`Client_process fullsessgrp) sitedata
-              (Eliom_common.make_persistent_full_group_name
-                 ~cookie_level:`Client_process
-                 sitedata.Eliom_common.site_dir_string (Some cookie)))
+         match cookie_level with
+         | `Client_process ->
+             (* We remove the session from its group: *)
+             remove sitedata cookie fullsessgrp >>= fun () ->
+             (* Then, we remove session data: *)
+             Eliom_common.Persistent_tables.remove_key_from_all_tables cookie
+         | `Session ->
+             remove_group ~cookie_level:(`Client_process fullsessgrp) sitedata
+               (Eliom_common.make_persistent_full_group_name
+                  ~cookie_level:`Client_process
+                  sitedata.Eliom_common.site_dir_string (Some cookie)))
       (function Not_found -> Lwt.return_unit | e -> Lwt.fail e)
 
   and remove _sitedata sess_id sess_grp =
@@ -545,17 +545,17 @@ module Pers = struct
         let sg = Eliom_common.string_of_perssessgrp sg0 in
         Lwt.catch
           (fun () ->
-            !!grouptable >>= fun grouptable ->
-            Ocsipersist.find grouptable sg >>= fun (max, cl) ->
-            let newcl = List.remove_first_if_any sess_id cl in
-            (* Before 2018-10-18, we were closing the session group
+             !!grouptable >>= fun grouptable ->
+             Ocsipersist.find grouptable sg >>= fun (max, cl) ->
+             let newcl = List.remove_first_if_any sess_id cl in
+             (* Before 2018-10-18, we were closing the session group
              when newcl was empty (no more session in the group).
              But persistent session groups are usually used to store persistent
              information about users. It makes no sense cleaning this
              information when user closes all their sessions.
              I remove this. -- Vincent
-          *)
-            Ocsipersist.replace_if_exists grouptable sg (max, newcl))
+             *)
+             Ocsipersist.replace_if_exists grouptable sg (max, newcl))
           (function Not_found -> Lwt.return_unit | e -> Lwt.fail e)
     | None -> Lwt.return_unit
 
@@ -566,10 +566,10 @@ module Pers = struct
         let sg = Eliom_common.string_of_perssessgrp sg in
         Lwt.catch
           (fun () ->
-            !!grouptable >>= fun grouptable ->
-            Ocsipersist.find grouptable sg >>= fun (max, cl) ->
-            let newcl = List.remove_first_if_any sess_id cl in
-            Ocsipersist.replace_if_exists grouptable sg (max, sess_id :: newcl))
+             !!grouptable >>= fun grouptable ->
+             Ocsipersist.find grouptable sg >>= fun (max, cl) ->
+             let newcl = List.remove_first_if_any sess_id cl in
+             Ocsipersist.replace_if_exists grouptable sg (max, sess_id :: newcl))
           (function Not_found -> Lwt.return_unit | e -> Lwt.fail e)
 
   let move sitedata ?set_max max sess_id grp1 grp2 =
